#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_gojot
----------------------------------

Tests for `gojot` module.
"""

import pytest

from contextlib import contextmanager
from click.testing import CliRunner
from os.path import isfile, isdir
from shutil import rmtree

from gojot import gojot
from gojot import cli


@pytest.fixture
def response():
    """Sample pytest fixture.
    See more at: http://doc.pytest.org/en/latest/fixture.html
    """
    # import requests
    # return requests.get('https://github.com/audreyr/cookiecutter-pypackage')


def test_content(response):
    """Sample pytest test function with the pytest fixture as an argument.
    """
    # from bs4 import BeautifulSoup
    # assert 'GitHub' in BeautifulSoup(response.content).title.string


def test_gojot():
    assert gojot.encode_str('teststring', 'testsalt') == '3of9iviQfPizfBuLhBS0'
    assert gojot.decode_str('3of9iviQfPizfBuLhBS0', 'testsalt') == 'teststring'
    assert '_' in gojot.random_name()
    gojot.git_clone('https://github.com/schollz/test5.git')
    assert isdir('test5') == True
    rmtree('test5')
    datas = gojot.parse_entries({'salt':'asldkfjalkdsfj'},"""
---
time: '2017-06-07 09:36:02'
entry: cool_entry1
---
Some text
---
time: '2017-06-07 09:36:03'
entry: cool_entry2
---
Some other text
""")
    assert len(datas) == 2
    assert datas[1] == {'hash': '911e2ea1b3fc4ffba9ed6ca14acaa506', 'meta': {
            'entry': 'cool_entry2', 'time': '2017-06-07 09:36:03'}, 'text': 'Some other text'}



# -*- coding: utf-8 -*-

import click
from gojot import gojot


@click.command()
@click.option('--repo', '-r', default=None, help='Repo to open.')
@click.option('--document', '-d', default=None, help='Document to open.')
@click.option('--import', '-i', 'imp', default=None, help='File to import.')
@click.option('--all', '-a', 'load_all', is_flag=True, help='Open all entries.')
@click.option('--edit', '-e', 'edit_one', is_flag=True, help='Edit an entry.')
@click.option('--export', '-x', 'export', is_flag=True, help='Export a document.')
@click.option('--stats', '-s', 'show_stats', is_flag=True, help='Show document stats.')
@click.option('--version', '-v', 'version', is_flag=True, help='Print version.')
def main(repo, document, imp, load_all, edit_one, export, show_stats, version, args=None):
    """gojot is a modern command-line journal that is distributed and encrypted by default."""
    click.echo("")
    click.echo("See gojot documentation at https://gojot.schollz.com/")
    if imp != None:
        gojot.run_import(repo, imp)
    elif version != False:
        print("gojot version 3.0.2")
    else:
        gojot.run(repo, document, load_all=load_all,
                  edit_one=edit_one, export=export, show_stats=show_stats)


if __name__ == "__main__":
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
    'pick',
    'hashids',
    'termcolor',
    'tqdm',
    'ruamel.yaml',
    'humanize',
    # TODO: put package requirements here
]

test_requirements = [
    'pick',
    'hashids',
    'termcolor',
    'tqdm',
    'ruamel.yaml',
    'humanize',
    # TODO: put package test requirements here
]

setup(
    name='gojot',
    version='3.0.2',
    description="A command-line journal that is distributed and encrypted, making it easy to jot notes.",
    long_description=readme + '\n\n' + history,
    author="Zack Scholl",
    author_email='zack.scholl@gmail.com',
    url='https://github.com/schollz/gojot',
    packages=[
        'gojot',
    ],
    package_dir={'gojot':
                 'gojot'},
    entry_points={
        'console_scripts': [
            'gojot=gojot.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=False,
    keywords='gojot',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)
